pub enum UuidError {
MutexPoisoned,
CounterExhausted(u32),
Clock(TimeError),
}Expand description
Error returned by next_v7_bytes.
Variants
MutexPoisoned
The MONO_STATE mutex was poisoned by a previous thread panic.
CounterExhausted(u32)
The 12-bit counter exhausted all 4 096 slots within a single millisecond and the system clock did not advance within the spin-wait budget (~5 ms).
Clock(TimeError)
The system clock could not be read (before epoch or timestamp overflow).